pub struct StoreData {
pub revision: u64,
pub categories: Vec<Category>,
pub labels: Vec<Label>,
pub tasks: Vec<Task>,
pub settings: Settings,
/* private fields */
}Fields
revision: u64categories: Vec<Category>labels: Vec<Label>tasks: Vec<Task>settings: SettingsImplementations
Sourceimpl StoreData
impl StoreData
pub fn attachments(&self) -> &[Attachment]
Sourcepub fn resolve_task_id(&self, query: &str) -> Result<String, StoreError>
pub fn resolve_task_id(&self, query: &str) -> Result<String, StoreError>
Resolve a task by full id or unique id prefix.
Sourcepub fn resolve_category_id(&self, query: &str) -> Result<String, StoreError>
pub fn resolve_category_id(&self, query: &str) -> Result<String, StoreError>
Resolve a category by id, Unicode-caseless name, or unique name prefix.
Sourcepub fn resolve_label_id(&self, query: &str) -> Result<String, StoreError>
pub fn resolve_label_id(&self, query: &str) -> Result<String, StoreError>
Resolve a label by id, Unicode-caseless name, or unique name prefix.
pub fn task(&self, id: &str) -> Result<&Task, StoreError>
pub fn category(&self, id: &str) -> Result<&Category, StoreError>
pub fn label(&self, id: &str) -> Result<&Label, StoreError>
pub fn create_task( &mut self, title: impl Into<String>, description: Vec<Block>, due: impl Into<String>, importance: u8, category_id: Option<String>, ) -> Result<Task, StoreError>
pub fn insert_task(&mut self, task: Task) -> Result<Task, StoreError>
pub fn edit_task( &mut self, id: &str, patch: TaskPatch, ) -> Result<Task, StoreError>
Sourcepub fn edit_task_if_unchanged(
&mut self,
expected: &Task,
patch: TaskPatch,
) -> Result<Task, StoreError>
pub fn edit_task_if_unchanged( &mut self, expected: &Task, patch: TaskPatch, ) -> Result<Task, StoreError>
Apply only the fields represented by patch, but fail if one of those
fields changed since expected was loaded. Unrelated concurrent edits
(for example toggling done while a title form is open) are preserved.
pub fn delete_task(&mut self, id: &str) -> Result<Task, StoreError>
pub fn set_task_done( &mut self, id: &str, done: bool, ) -> Result<Task, StoreError>
pub fn toggle_task_done(&mut self, id: &str) -> Result<Task, StoreError>
pub fn set_task_importance( &mut self, id: &str, importance: u8, ) -> Result<Task, StoreError>
pub fn set_task_category( &mut self, id: &str, category_id: Option<String>, ) -> Result<Task, StoreError>
pub fn set_task_labels( &mut self, id: &str, label_ids: Vec<String>, ) -> Result<Task, StoreError>
pub fn move_task(&mut self, id: &str, target: usize) -> Result<(), StoreError>
pub fn move_task_relative( &mut self, id: &str, target_id: &str, position: RelativePosition, ) -> Result<Task, StoreError>
pub fn purge_completed( &mut self, scope: &PurgeScope, ) -> Result<Vec<Task>, StoreError>
Sourcepub fn purge_completed_ids(
&mut self,
ids: &[String],
) -> Result<Vec<Task>, StoreError>
pub fn purge_completed_ids( &mut self, ids: &[String], ) -> Result<Vec<Task>, StoreError>
Purge only the completed tasks captured by a confirmation prompt.
pub fn create_category( &mut self, name: impl Into<String>, description: impl Into<String>, ) -> Result<Category, StoreError>
Sourcepub fn ensure_category(
&mut self,
name: impl Into<String>,
description: Option<String>,
) -> Result<(Category, bool), StoreError>
pub fn ensure_category( &mut self, name: impl Into<String>, description: Option<String>, ) -> Result<(Category, bool), StoreError>
Return the category with this exact name identity, or create it. Supplied metadata is an assertion and never edits an existing category.
pub fn insert_category( &mut self, category: Category, ) -> Result<Category, StoreError>
pub fn edit_category( &mut self, id: &str, patch: CategoryPatch, ) -> Result<Category, StoreError>
pub fn edit_category_if_unchanged( &mut self, expected: &Category, patch: CategoryPatch, ) -> Result<Category, StoreError>
Sourcepub fn delete_category(&mut self, id: &str) -> Result<Category, StoreError>
pub fn delete_category(&mut self, id: &str) -> Result<Category, StoreError>
Delete a category while preserving its tasks as uncategorized.
pub fn create_label( &mut self, name: impl Into<String>, ) -> Result<Label, StoreError>
Sourcepub fn ensure_label(
&mut self,
name: impl Into<String>,
color: Option<LabelColor>,
) -> Result<(Label, bool), StoreError>
pub fn ensure_label( &mut self, name: impl Into<String>, color: Option<LabelColor>, ) -> Result<(Label, bool), StoreError>
Return the label with this exact name identity, or create it. A supplied color is an assertion and never recolors an existing label.
pub fn create_label_with_color( &mut self, name: impl Into<String>, color: LabelColor, ) -> Result<Label, StoreError>
pub fn insert_label(&mut self, label: Label) -> Result<Label, StoreError>
pub fn edit_label( &mut self, id: &str, patch: LabelPatch, ) -> Result<Label, StoreError>
Sourcepub fn delete_label(&mut self, id: &str) -> Result<Label, StoreError>
pub fn delete_label(&mut self, id: &str) -> Result<Label, StoreError>
Delete a global label while preserving every task that used it.
pub fn move_category( &mut self, id: &str, target: usize, ) -> Result<(), StoreError>
pub fn move_category_relative( &mut self, id: &str, target_id: &str, position: RelativePosition, ) -> Result<Category, StoreError>
pub fn replace_settings( &mut self, settings: Settings, ) -> Result<Settings, StoreError>
pub fn update_settings( &mut self, operation: impl FnOnce(&mut Settings), ) -> Result<Settings, StoreError>